@@ -4,6 +4,9 @@
 #' \strong{\code{show}} makes an element visible, \strong{\code{hide}} makes
 #' an element invisible, \strong{\code{toggle}} displays the element if it it
 #' hidden and hides it if it is visible.\cr\cr
+#' \strong{\code{showElement}}, \strong{\code{hideElement}}, and
+#' \strong{\code{toggleElement}} are synonyms that may be safer to use if you're
+#' working with S4 classes (since they don't mask any existing S4 functions).\cr\cr
 #' If \code{condition} is given to \code{toggle}, that condition will be used
 #' to determine if to show or hide the element. The element will be shown if the
 #' condition evaluates to \code{TRUE} and hidden otherwise. If you find
@@ -13,11 +16,15 @@
 #' If you want to hide/show an element in a few seconds rather than immediately,
 #' you can use the \code{\link[shinyjs]{delay}} function.
 #'
+#' @note If you use S4 classes, you should be aware of the fact that both S4 and
+#' \code{shinyjs} use the \code{show()} function. This means that when using S4,
+#' it is recommended to use \code{showElement()} from \code{shinyjs}, and to
+#' use \code{methods::show()} for S4 object.
+#'
 #' @param id The id of the element/Shiny tag
-#' @param anim If \code{TRUE} then animate the behaviour (default: \code{FALSE})
+#' @param anim If \code{TRUE} then animate the behaviour
 #' @param animType The type of animation to use, either \code{"slide"} or \code{"fade"}
-#' (default: \code{"slide"})
-#' @param time The number of seconds to make the animation last (default: \code{0.5})
+#' @param time The number of seconds to make the animation last
 #' @param selector JQuery selector of the elements to show/hide. Ignored if the
 #' \code{id} argument is given. For example, to select all span elements with
 #' class x, use \code{selector = "span.x"}
@@ -81,24 +88,42 @@ NULL
 
 #' @export
 #' @rdname visibilityFuncs
-show <- function(id, anim, animType, time, selector) {
+show <- function(id = NULL, anim = FALSE, animType = "slide", time = 0.5,
+                 selector = NULL) {
   fxn <- "show"
-  params <- as.list(match.call())[-1]
+  params <- list(id = id, anim = anim, animType = animType,
+                 time = time, selector = selector)
   jsFuncHelper(fxn, params)
 }
 
 #' @export
 #' @rdname visibilityFuncs
-hide <- function(id, anim, animType, time, selector) {
+showElement <- show
+
+#' @export
+#' @rdname visibilityFuncs
+hide <- function(id = NULL, anim = FALSE, animType = "slide", time = 0.5,
+                 selector = NULL) {
   fxn <- "hide"
-  params <- as.list(match.call())[-1]
+  params <- list(id = id, anim = anim, animType = animType,
+                 time = time, selector = selector)
   jsFuncHelper(fxn, params)
 }
 
 #' @export
 #' @rdname visibilityFuncs
-toggle <- function(id, anim, animType, time, selector, condition) {
+hideElement <- hide
+
+#' @export
+#' @rdname visibilityFuncs
+toggle <- function(id = NULL, anim = FALSE, animType = "slide", time = 0.5,
+                   selector = NULL, condition = NULL) {
   fxn <- "toggle"
-  params <- as.list(match.call())[-1]
+  params <- list(id = id, anim = anim, animType = animType,
+                 time = time, selector = selector, condition = condition)
   jsFuncHelper(fxn, params)
 }
+
+#' @export
+#' @rdname visibilityFuncs
+toggleElement <- toggle
